"""Main entry point for hanzo-mcp when run as a module."""

import warnings

# Suppress ALL Pydantic deprecation warnings before any imports
warnings.filterwarnings(
    "ignore", 
    category=DeprecationWarning,
    module="pydantic.*"
)

# Also try to catch the specific message pattern
warnings.filterwarnings(
    "ignore",
    message=".*class-based.*config.*deprecated.*"
)

# Import cli after setting up warnings
from hanzo_mcp.cli import main

if __name__ == "__main__":
    main()


"""Hanzo MCP - Implementation of Hanzo capabilities using MCP."""

import warnings

# Aggressively suppress ALL deprecation warnings from pydantic before any imports
warnings.filterwarnings("ignore", category=DeprecationWarning, module="pydantic.*")
warnings.filterwarnings("ignore", category=DeprecationWarning, module="pydantic._internal.*")
warnings.filterwarnings("ignore", category=DeprecationWarning, module="litellm.*")

# Also catch specific patterns
warnings.filterwarnings("ignore", message=".*class-based.*config.*deprecated.*")
warnings.filterwarnings("ignore", message=".*PydanticDeprecatedSince20.*")

__version__ = "0.6.8"
